#
# spec file for package cura-engine
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cura-engine
%define sversion 4.13.1
Version:        4.13.1
Release:        3.1
Summary:        3D printer control software
License:        AGPL-3.0-only
Group:          Hardware/Printing
URL:            https://github.com/Ultimaker/CuraEngine
Source0:        https://github.com/Ultimaker/CuraEngine/archive/%{sversion}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        CuraEngine.1
# X-OPENSUSE-PATCH fix-build.patch follow openSUSE policies
Patch1:         fix-build.patch
# PATCH-FIX-UPSTREAM add-missing-include.patch -- Add missing include <cstdint>
Patch2:         add-missing-include.patch
# PATCH-FIX-OPENSUSE
Patch3:         0001-Fix-failing-build-due-to-missing-iomanip.h-include.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  gmock
BuildRequires:  gtest
BuildRequires:  libArcus-devel >= %{version}
BuildRequires:  stb-devel
BuildRequires:  cmake(RapidJSON)
BuildRequires:  pkgconfig(polyclipping)
# No 32bit support anymore
ExcludeArch:    %ix86 %arm s390

%description
CuraEngine is an engine for processing 3D models into 3D printing
instruction for Ultimaker and other GCode-based 3D printers.
It is part of the larger project called "Cura".

%prep
%autosetup -p1 -n CuraEngine-%sversion
# the test is hardcoding the version number
sed -i -e 's,"master","%{version}",' tests/GCodeExportTest.cpp

%build
# make sure lib_CuraEngine is statically build and linked
%cmake -DCURA_ENGINE_VERSION=%version \
       -DCMAKE_POSITION_INDEPENDENT_CODE="true" \
       -DBUILD_SHARED_LIBS="false" \
       -DUSE_SYSTEM_LIBS=ON \
       -DBUILD_TESTS=ON
%cmake_build

%install
%cmake_install

install -Dm0644 %{SOURCE1} %{buildroot}%{_mandir}/man1/CuraEngine.1

%check
# we don't use "make test" to get the output on failure
%ctest

%files
%license LICENSE
%doc README.md
%_bindir/CuraEngine
%_mandir/man1/CuraEngine.1*

%changelog
* Wed Nov 27 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build with latest GCC, add
  0001-Fix-failing-build-due-to-missing-iomanip.h-include.patch
- Minor spec file cleanup
* Tue May  2 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add add-missing-include.patch: Add missing include <cstdint>
* Sun Feb  6 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 4.13.1
  Release notes:
  * https://github.com/Ultimaker/Cura/releases/tag/4.13.1
* Thu Jan 27 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to version 4.13.0
  Release notes:
  * https://github.com/Ultimaker/Cura/releases/tag/4.13.0
- Refresh patch:
  * fix-build.patch
* Mon Apr 26 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 4.9.0
  Release notes:
  * https://github.com/Ultimaker/Cura/releases/tag/4.9
* Tue Nov 10 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 4.8.0
  Release notes:
  * https://github.com/Ultimaker/Cura/releases/tag/4.8
- Use system RapidJSON and polyclipping when available
* Tue Sep 15 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 4.7.1
  Release notes:
  * https://github.com/Ultimaker/Cura/releases/tag/4.7.1
  * https://github.com/Ultimaker/Cura/releases/tag/4.7.0
  * https://github.com/Ultimaker/Cura/releases/tag/4.6.2
* Sun Jun  7 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 4.6.1
  Release notes:
  * https://github.com/Ultimaker/Cura/releases/tag/4.6.1
  * https://github.com/Ultimaker/Cura/releases/tag/4.6.0
  * https://github.com/Ultimaker/Cura/releases/tag/4.5.0
- Clean up spec file
* Thu Jan  2 2020 Adrian Schröter <adrian@suse.de>
- update to version 4.4.1
  Release notes:
  * https://github.com/Ultimaker/Cura/releases/tag/v4.4.1
* Fri Nov 22 2019 Adrian Schröter <adrian@suse.de>
- update to version 4.4.0
  Release notes:
  * https://github.com/Ultimaker/Cura/releases/tag/v4.4.0
* Fri Sep 27 2019 Adrian Schröter <adrian@suse.de>
- update to version 4.3.0
  Release notes:
  * https://github.com/Ultimaker/Cura/releases/tag/4.3.0
- obsoletes CuraEngine-gcc9.patch
* Mon Aug 12 2019 Adrian Schröter <adrian@suse.de>
- update to version 4.2.0
  * https://ultimaker.com/en/blog/52912-ultimaker-cura-42-first-choice-for-3d-printing-professionals-worldwide
* Thu Jun 13 2019 Adrian Schröter <adrian@suse.de>
- update to version 4.1.0
  * https://ultimaker.com/en/products/ultimaker-cura-software/release-notes
- enable tests
- some build fixes needed:
  fix-build.patch
  CuraEngine-gcc9.patch
- 32bit platform is unsupported on Linux
  (builds, but testcases are failing)
* Thu Apr 18 2019 Adrian Schröter <adrian@suse.de>
- sync spec file with -lulzbot variant
- enable test suite (requires fix-build.patch for libArcus interface)
* Sat Mar  9 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update URL to use https
* Fri Jan 18 2019 Adrian Schröter <adrian@suse.de>
- define version explicit for reporting in gcode files
* Wed Jan  2 2019 Adrian Schröter <adrian@suse.de>
- fix build with stb in subdirectory
  * obsoletes fix-build.patch
* Fri Nov 16 2018 Adrian Schröter <adrian@suse.de>
- update to version 3.6.0
  https://ultimaker.com/en/products/ultimaker-cura-software/release-notes
* Wed Oct 17 2018 Adrian Schröter <adrian@suse.de>
- update to version 3.5.1
  https://ultimaker.com/en/products/ultimaker-cura-software/release-notes
- replaced fix-build.patch with new need
* Thu Jul 26 2018 jengelh@inai.de
- Trim bias from description.
* Mon Jul 16 2018 adrian@suse.de
- update to version 3.4.1
  https://ultimaker.com/en/products/ultimaker-cura-software/release-notes
* Mon Jul  9 2018 adrian@suse.de
- update to version 3.3.0
  * No official release notes
* Tue Apr  3 2018 adrian@suse.de
- update to version 3.2.1
  * new algorithm and lot's of smaller improvements
* Sat Jan 27 2018 stefan.bruens@rwth-aachen.de
- Link private lib_CuraEngine statically to binary
* Thu Jan 25 2018 adrian@suse.de
- update to version 3.1.0
* Fri Dec  8 2017 stefan.bruens@rwth-aachen.de
- Fix License, Cura 3.0 and libraries are LGPL-3.0 now
* Thu Dec  7 2017 stefan.bruens@rwth-aachen.de
- Revert parts of the previous commit breaking build on anything
  but Leap 42.3
* Fri Nov  3 2017 adrian@suse.de
- update to version 3.0.3
* Tue Sep 12 2017 stefan.bruens@rwth-aachen.de
- Fixed RPM Group
- Fix build on TW, parallel installation of gcc6/7 causes build errors
- Build CuraEngine as PIE
* Mon Sep  4 2017 adrian@suse.de
- update to version 2.7.0
* Mon Jun 26 2017 adrian@suse.de
- update to version 2.6.0
* Fri Dec 23 2016 adrian@suse.de
- update to stable 15.04.6 release
  (15.06 has changed interface which breaks all dependending tools atm)
* Sat Oct 12 2013 lzwang@suse.com
- Initial package of CuraEngine
